@@ -1,5 +1,5 @@
 from .computation_engine import apply, join, summarize, Engine, files_from, DelayedException
-from .fs_cache import CacheBuilder
+from .fs_cache import CacheBuilder, LocalCacheBuilder
 from .std_logger import get_logger
 
 # DO NOT TOUCH THE FOLLOWING LINE:
